..
    Copyright (C) 2020 CESNET.

    OARepo Micro API is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 3.3.106
 - after fixed oarepo-heartbeat/pycodestyle/isort ...

Version 3.3.107
 - importlib_metadata added to reqs.
